@@ -34,16 +34,16 @@ Folder Folder::Parser::parseXml(QXmlStreamReader& xml)
         xml.readNext();
 
         if (xml.isStartElement()) {
-            if (xml.name() == "id") {
+            if (xml.name() == QLatin1String("id")) {
                 folder.setId(xml.readElementText());
-            } else if (xml.name() == "name") {
+            } else if (xml.name() == QLatin1String("name")) {
                 folder.setName(xml.readElementText());
-            } else if (xml.name() == "messagecount") {
+            } else if (xml.name() == QLatin1String("messagecount")) {
                 folder.setMessageCount(xml.readElementText().toInt());
-            } else if (xml.name() == "type") {
+            } else if (xml.name() == QLatin1String("type")) {
                 folder.setType(xml.readElementText());
             }
-        } else if (xml.isEndElement() && xml.name() == "folder") {
+        } else if (xml.isEndElement() && xml.name() == QLatin1String("folder")) {
             break;
         }
     }
