@@ -36,15 +36,15 @@ License License::Parser::parseXml(QXmlStreamReader& xml)
     while ( !xml.atEnd() ) {
         xml.readNext();
         if ( xml.isStartElement() ) {
-            if ( xml.name() == "id" ) {
+            if ( xml.name() == QLatin1String("id" )) {
                 item.setId( xml.readElementText().toInt() );
-            } else if ( xml.name() == "name" ) {
+            } else if ( xml.name() == QLatin1String("name" )) {
                 item.setName( xml.readElementText() );
-            } else if ( xml.name() == "link" ) {
+            } else if ( xml.name() == QLatin1String("link" )) {
                 item.setUrl( xml.readElementText() );
             }
         }
-        if (xml.isEndElement() && xml.name() == "license") {
+        if (xml.isEndElement() && xml.name() == QLatin1String("license")) {
             break;
         }
     }
