@@ -520,7 +520,7 @@ ListJob<Activity>* Provider::requestActivities()
         return 0;
     }
 
-    qDebug() << "request activity";
+    //qDebug() << "request activity";
     QUrl url = createUrl( QLatin1String( "activity" ) );
     return doRequestActivityList( url );
 }
@@ -532,7 +532,7 @@ ListJob<Project>* Provider::requestProjects()
         return 0;
     }
 
-    qDebug() << "request projects";
+    //qDebug() << "request projects";
     QUrl url = createUrl( QLatin1String("buildservice/project/list") );
     return new ListJob<Project>(d->m_internals, createRequest(url));
 }
@@ -544,7 +544,7 @@ ItemJob<Project>* Provider::requestProject(const QString& id)
     }
 
     QUrl url = createUrl( QLatin1String("buildservice/project/get/") + id );
-    qDebug() << url;
+    //qDebug() << url;
     return new ItemJob<Project>(d->m_internals, createRequest(url));
 }
 
@@ -676,7 +676,7 @@ ItemJob<BuildServiceJobOutput>* Provider::requestBuildServiceJobOutput(const QSt
     }
 
     QUrl url = createUrl( QLatin1String("buildservice/jobs/getoutput/") + id );
-    qDebug() << url;
+    //qDebug() << url;
     return new ItemJob<BuildServiceJobOutput>(d->m_internals, createRequest(url));
 }
 
@@ -687,7 +687,7 @@ ItemJob<BuildServiceJob>* Provider::requestBuildServiceJob(const QString &id)
     }
 
     QUrl url = createUrl( QLatin1String("buildservice/jobs/get/") + id );
-    qDebug() << url;
+    //qDebug() << url;
     return new ItemJob<BuildServiceJob>(d->m_internals, createRequest(url));
 }
 
@@ -719,7 +719,7 @@ PostJob* Provider::cancelBuildServiceJob(const BuildServiceJob& job)
 
     StringMap postParameters;
     postParameters.insert(QLatin1String("dummyparameter"), QLatin1String("dummyvalue"));
-    qDebug() << "b....................b";
+    //qDebug() << "b....................b";
     return new PostJob(d->m_internals, createRequest(
                        QLatin1String("buildservice/jobs/cancel/") + job.id()), postParameters);
 }
@@ -735,7 +735,7 @@ PostJob* Provider::createBuildServiceJob(const BuildServiceJob& job)
     // so even while we don't need any in this case,
     // we add dummy data to the request
     postParameters.insert(QLatin1String("dummyparameter"), QLatin1String("dummyvalue"));
-    qDebug() << "Creating new BSJ on" << job.buildServiceId();
+    //qDebug() << "Creating new BSJ on" << job.buildServiceId();
     return new PostJob(d->m_internals, createRequest(
                        QLatin1String("buildservice/jobs/create/") +
                            job.projectId() + QLatin1Char('/') + job.buildServiceId()  + QLatin1Char('/') + job.target()),
@@ -748,7 +748,7 @@ ListJob<BuildService>* Provider::requestBuildServices()
         return 0;
     }
 
-    qDebug() << "request projects";
+    //qDebug() << "request projects";
     QUrl url = createUrl( QLatin1String("buildservice/buildservices/list") );
     return new ListJob<BuildService>(d->m_internals, createRequest(url));
 }
@@ -801,7 +801,7 @@ PostJob* Provider::createRemoteAccount(const RemoteAccount& account)
     postParameters.insert(QLatin1String("type"), account.type());
     postParameters.insert(QLatin1String("typeid"), account.remoteServiceId()); // FIXME: remoteserviceid?
     postParameters.insert(QLatin1String("data"), account.data());
-    qDebug() << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
+    //qDebug() << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
     return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/remoteaccounts/add")),
                        postParameters);
 }
@@ -821,7 +821,7 @@ PostJob* Provider::editRemoteAccount(const RemoteAccount& account)
     postParameters.insert(QLatin1String("type"), account.type());
     postParameters.insert(QLatin1String("typeid"), account.remoteServiceId()); // FIXME: remoteserviceid?
     postParameters.insert(QLatin1String("data"), account.data());
-    qDebug() << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
+    //qDebug() << "Creating new Remoteaccount" << account.id() << account.login() << account.password();
     return new PostJob(d->m_internals, createRequest(QLatin1String("buildservice/remoteaccounts/edit/") + account.id()),
                        postParameters);
 }
@@ -833,7 +833,7 @@ ItemJob<RemoteAccount>* Provider::requestRemoteAccount(const QString &id)
     }
 
     QUrl url = createUrl( QLatin1String("buildservice/remoteaccounts/get/") + id );
-    qDebug() << url;
+    //qDebug() << url;
     return new ItemJob<RemoteAccount>(d->m_internals, createRequest(url));
 }
 
@@ -856,7 +856,7 @@ PostJob* Provider::uploadTarballToBuildService(const QString& projectId, const Q
     }
 
     QUrl url = createUrl(QLatin1String( "buildservice/project/uploadsource/" ) + projectId);
-    qDebug() << "Up'ing tarball" << url << projectId << fileName << payload;
+    //qDebug() << "Up'ing tarball" << url << projectId << fileName << payload;
     PostFileData postRequest(url);
     postRequest.addFile(fileName, payload, QLatin1String( "application/octet-stream" ), QLatin1String("source"));
     return new PostJob(d->m_internals, postRequest.request(), postRequest.data());
@@ -1120,7 +1120,7 @@ ItemPostJob<Content>* Provider::addNewContent(const Category& category, const Co
     pars.insert(QLatin1String( "type" ), category.id());
     pars.insert(QLatin1String( "name" ), cont.name());
 
-    qDebug() << "Parameter map: " << pars;
+    //qDebug() << "Parameter map: " << pars;
 
     return new ItemPostJob<Content>(d->m_internals, createRequest(url), pars);
 }
@@ -1139,7 +1139,7 @@ ItemPostJob<Content>* Provider::editContent(const Category& updatedCategory, con
     pars.insert(QLatin1String( "type" ), updatedCategory.id());
     pars.insert(QLatin1String( "name" ), updatedContent.name());
 
-    qDebug() << "Parameter map: " << pars;
+    //qDebug() << "Parameter map: " << pars;
 
     return new ItemPostJob<Content>(d->m_internals, createRequest(url), pars);
 }
@@ -1232,7 +1232,7 @@ PostJob* Provider::voteForContent(const QString& contentId, bool positiveVote)
 
     StringMap postParameters;
     postParameters.insert(QLatin1String( "vote" ), positiveVote ? QLatin1String( "good" ) : QLatin1String( "bad" ));
-    qDebug() << "vote: " << positiveVote;
+    //qDebug() << "vote: " << positiveVote;
     return new PostJob(d->m_internals, createRequest(QLatin1String( "content/vote/" ) + contentId), postParameters);
 }
 
@@ -1250,7 +1250,7 @@ PostJob* Provider::voteForContent(const QString& contentId, uint rating)
 
     StringMap postParameters;
     postParameters.insert(QLatin1String( "vote" ), QString::number(rating));
-    qDebug() << "vote: " << QString::number(rating);
+    //qDebug() << "vote: " << QString::number(rating);
     return new PostJob(d->m_internals, createRequest(QLatin1String( "content/vote/" ) + contentId), postParameters);
 }
 
@@ -1542,7 +1542,7 @@ QUrl Provider::createUrl(const QString& path)
 QNetworkRequest Provider::createRequest(const QUrl& url)
 {
     QNetworkRequest request(url);
-    qDebug() << "OCS Request:" << url;
+    //qDebug() << "OCS Request:" << url;
     if (!d->m_credentialsUserName.isEmpty()) {
         QString concatenated = d->m_credentialsUserName + QLatin1Char( ':' ) + d->m_credentialsPassword;
         QByteArray data = concatenated.toLocal8Bit().toBase64();
